@@ -730,7 +730,11 @@ static uint16_t DNSResponseGetNameByOffset(const uint8_t * const input, const ui
         }
         qdata += length;
 
-        if ((uint64_t)((qdata + 1) - input) >= (uint64_t)input_len) {
+        /* if we're at the end of the input data, we're done */
+        if ((uint64_t)((qdata + 1) - input) == (uint64_t)input_len) {
+            break;
+        }
+        else if ((uint64_t)((qdata + 1) - input) > (uint64_t)input_len) {
             SCLogDebug("input buffer too small");
             goto insufficient_data;
         }
@@ -979,6 +983,12 @@ const uint8_t *DNSReponseParse(DNSState *dns_state, const DNSHeader * const dns_
         case DNS_RECORD_TYPE_TXT:
         {
             uint16_t datalen = ntohs(head->len);
+
+            if (datalen == 0) {
+                DNSSetEvent(dns_state, DNS_DECODER_EVENT_MALFORMED_DATA);
+                goto bad_data;
+            }
+
             uint8_t txtlen = *data;
             const uint8_t *tdata = data + 1;
 
